// Licensed to the .NET Foundation under one or more agreements.
// The .NET Foundation licenses this file to you under the MIT license.
// See the LICENSE file in the project root for more information.
// ------------------------------------------------------------------------------
// Changes to this file must follow the http://aka.ms/api-review process.
// ------------------------------------------------------------------------------
[assembly: System.Runtime.CompilerServices.CompilationRelaxations(8)]
[assembly: System.Runtime.CompilerServices.RuntimeCompatibility(WrapNonExceptionThrows = true)]
[assembly: System.Diagnostics.Debuggable(System.Diagnostics.DebuggableAttribute.DebuggingModes.IgnoreSymbolStoreSequencePoints)]
[assembly: System.Security.AllowPartiallyTrustedCallers]
[assembly: System.Runtime.CompilerServices.ReferenceAssembly]
[assembly: System.Reflection.AssemblyTitle("System.Runtime.Extensions")]
[assembly: System.Reflection.AssemblyDescription("System.Runtime.Extensions")]
[assembly: System.Reflection.AssemblyDefaultAlias("System.Runtime.Extensions")]
[assembly: System.Reflection.AssemblyCompany("Microsoft Corporation")]
[assembly: System.Reflection.AssemblyProduct("Microsoft® .NET Framework")]
[assembly: System.Reflection.AssemblyCopyright("© Microsoft Corporation.  All rights reserved.")]
[assembly: System.Reflection.AssemblyFileVersion("4.6.23123.00")]
[assembly: System.Reflection.AssemblyInformationalVersion("4.6.23123.00 built by: PROJECTKREL")]
[assembly: System.CLSCompliant(true)]
[assembly: System.Reflection.AssemblyMetadata("", "")]
[assembly: System.Reflection.AssemblyVersionAttribute("4.0.10.0")]
[assembly: System.Reflection.AssemblyFlagsAttribute((System.Reflection.AssemblyNameFlags)0x70)]
namespace System
{
    public static partial class BitConverter
    {
        public static readonly bool IsLittleEndian;
        public static long DoubleToInt64Bits(double value) { throw null; }

        public static byte[] GetBytes(bool value) { throw null; }

        public static byte[] GetBytes(char value) { throw null; }

        public static byte[] GetBytes(double value) { throw null; }

        public static byte[] GetBytes(short value) { throw null; }

        public static byte[] GetBytes(int value) { throw null; }

        public static byte[] GetBytes(long value) { throw null; }

        public static byte[] GetBytes(float value) { throw null; }

        [CLSCompliant(false)]
        public static byte[] GetBytes(ushort value) { throw null; }

        [CLSCompliant(false)]
        public static byte[] GetBytes(uint value) { throw null; }

        [CLSCompliant(false)]
        public static byte[] GetBytes(ulong value) { throw null; }

        public static double Int64BitsToDouble(long value) { throw null; }

        public static bool ToBoolean(byte[] value, int startIndex) { throw null; }

        public static char ToChar(byte[] value, int startIndex) { throw null; }

        public static double ToDouble(byte[] value, int startIndex) { throw null; }

        public static short ToInt16(byte[] value, int startIndex) { throw null; }

        public static int ToInt32(byte[] value, int startIndex) { throw null; }

        public static long ToInt64(byte[] value, int startIndex) { throw null; }

        public static float ToSingle(byte[] value, int startIndex) { throw null; }

        public static string ToString(byte[] value, int startIndex, int length) { throw null; }

        public static string ToString(byte[] value, int startIndex) { throw null; }

        public static string ToString(byte[] value) { throw null; }

        [CLSCompliant(false)]
        public static ushort ToUInt16(byte[] value, int startIndex) { throw null; }

        [CLSCompliant(false)]
        public static uint ToUInt32(byte[] value, int startIndex) { throw null; }

        [CLSCompliant(false)]
        public static ulong ToUInt64(byte[] value, int startIndex) { throw null; }
    }

    public static partial class Convert
    {
        public static object ChangeType(object value, Type conversionType, IFormatProvider provider) { throw null; }

        public static object ChangeType(object value, Type conversionType) { throw null; }

        public static object ChangeType(object value, TypeCode typeCode, IFormatProvider provider) { throw null; }

        public static byte[] FromBase64CharArray(char[] inArray, int offset, int length) { throw null; }

        public static byte[] FromBase64String(string s) { throw null; }

        public static TypeCode GetTypeCode(object value) { throw null; }

        public static int ToBase64CharArray(byte[] inArray, int offsetIn, int length, char[] outArray, int offsetOut) { throw null; }

        public static string ToBase64String(byte[] inArray, int offset, int length) { throw null; }

        public static string ToBase64String(byte[] inArray) { throw null; }

        public static bool ToBoolean(bool value) { throw null; }

        public static bool ToBoolean(byte value) { throw null; }

        public static bool ToBoolean(decimal value) { throw null; }

        public static bool ToBoolean(double value) { throw null; }

        public static bool ToBoolean(short value) { throw null; }

        public static bool ToBoolean(int value) { throw null; }

        public static bool ToBoolean(long value) { throw null; }

        public static bool ToBoolean(object value, IFormatProvider provider) { throw null; }

        public static bool ToBoolean(object value) { throw null; }

        [CLSCompliant(false)]
        public static bool ToBoolean(sbyte value) { throw null; }

        public static bool ToBoolean(float value) { throw null; }

        public static bool ToBoolean(string value, IFormatProvider provider) { throw null; }

        public static bool ToBoolean(string value) { throw null; }

        [CLSCompliant(false)]
        public static bool ToBoolean(ushort value) { throw null; }

        [CLSCompliant(false)]
        public static bool ToBoolean(uint value) { throw null; }

        [CLSCompliant(false)]
        public static bool ToBoolean(ulong value) { throw null; }

        public static byte ToByte(bool value) { throw null; }

        public static byte ToByte(byte value) { throw null; }

        public static byte ToByte(char value) { throw null; }

        public static byte ToByte(decimal value) { throw null; }

        public static byte ToByte(double value) { throw null; }

        public static byte ToByte(short value) { throw null; }

        public static byte ToByte(int value) { throw null; }

        public static byte ToByte(long value) { throw null; }

        public static byte ToByte(object value, IFormatProvider provider) { throw null; }

        public static byte ToByte(object value) { throw null; }

        [CLSCompliant(false)]
        public static byte ToByte(sbyte value) { throw null; }

        public static byte ToByte(float value) { throw null; }

        public static byte ToByte(string value, IFormatProvider provider) { throw null; }

        public static byte ToByte(string value, int fromBase) { throw null; }

        public static byte ToByte(string value) { throw null; }

        [CLSCompliant(false)]
        public static byte ToByte(ushort value) { throw null; }

        [CLSCompliant(false)]
        public static byte ToByte(uint value) { throw null; }

        [CLSCompliant(false)]
        public static byte ToByte(ulong value) { throw null; }

        public static char ToChar(byte value) { throw null; }

        public static char ToChar(short value) { throw null; }

        public static char ToChar(int value) { throw null; }

        public static char ToChar(long value) { throw null; }

        public static char ToChar(object value, IFormatProvider provider) { throw null; }

        public static char ToChar(object value) { throw null; }

        [CLSCompliant(false)]
        public static char ToChar(sbyte value) { throw null; }

        public static char ToChar(string value, IFormatProvider provider) { throw null; }

        public static char ToChar(string value) { throw null; }

        [CLSCompliant(false)]
        public static char ToChar(ushort value) { throw null; }

        [CLSCompliant(false)]
        public static char ToChar(uint value) { throw null; }

        [CLSCompliant(false)]
        public static char ToChar(ulong value) { throw null; }

        public static DateTime ToDateTime(object value, IFormatProvider provider) { throw null; }

        public static DateTime ToDateTime(object value) { throw null; }

        public static DateTime ToDateTime(string value, IFormatProvider provider) { throw null; }

        public static DateTime ToDateTime(string value) { throw null; }

        public static decimal ToDecimal(bool value) { throw null; }

        public static decimal ToDecimal(byte value) { throw null; }

        public static decimal ToDecimal(decimal value) { throw null; }

        public static decimal ToDecimal(double value) { throw null; }

        public static decimal ToDecimal(short value) { throw null; }

        public static decimal ToDecimal(int value) { throw null; }

        public static decimal ToDecimal(long value) { throw null; }

        public static decimal ToDecimal(object value, IFormatProvider provider) { throw null; }

        public static decimal ToDecimal(object value) { throw null; }

        [CLSCompliant(false)]
        public static decimal ToDecimal(sbyte value) { throw null; }

        public static decimal ToDecimal(float value) { throw null; }

        public static decimal ToDecimal(string value, IFormatProvider provider) { throw null; }

        public static decimal ToDecimal(string value) { throw null; }

        [CLSCompliant(false)]
        public static decimal ToDecimal(ushort value) { throw null; }

        [CLSCompliant(false)]
        public static decimal ToDecimal(uint value) { throw null; }

        [CLSCompliant(false)]
        public static decimal ToDecimal(ulong value) { throw null; }

        public static double ToDouble(bool value) { throw null; }

        public static double ToDouble(byte value) { throw null; }

        public static double ToDouble(decimal value) { throw null; }

        public static double ToDouble(double value) { throw null; }

        public static double ToDouble(short value) { throw null; }

        public static double ToDouble(int value) { throw null; }

        public static double ToDouble(long value) { throw null; }

        public static double ToDouble(object value, IFormatProvider provider) { throw null; }

        public static double ToDouble(object value) { throw null; }

        [CLSCompliant(false)]
        public static double ToDouble(sbyte value) { throw null; }

        public static double ToDouble(float value) { throw null; }

        public static double ToDouble(string value, IFormatProvider provider) { throw null; }

        public static double ToDouble(string value) { throw null; }

        [CLSCompliant(false)]
        public static double ToDouble(ushort value) { throw null; }

        [CLSCompliant(false)]
        public static double ToDouble(uint value) { throw null; }

        [CLSCompliant(false)]
        public static double ToDouble(ulong value) { throw null; }

        public static short ToInt16(bool value) { throw null; }

        public static short ToInt16(byte value) { throw null; }

        public static short ToInt16(char value) { throw null; }

        public static short ToInt16(decimal value) { throw null; }

        public static short ToInt16(double value) { throw null; }

        public static short ToInt16(short value) { throw null; }

        public static short ToInt16(int value) { throw null; }

        public static short ToInt16(long value) { throw null; }

        public static short ToInt16(object value, IFormatProvider provider) { throw null; }

        public static short ToInt16(object value) { throw null; }

        [CLSCompliant(false)]
        public static short ToInt16(sbyte value) { throw null; }

        public static short ToInt16(float value) { throw null; }

        public static short ToInt16(string value, IFormatProvider provider) { throw null; }

        public static short ToInt16(string value, int fromBase) { throw null; }

        public static short ToInt16(string value) { throw null; }

        [CLSCompliant(false)]
        public static short ToInt16(ushort value) { throw null; }

        [CLSCompliant(false)]
        public static short ToInt16(uint value) { throw null; }

        [CLSCompliant(false)]
        public static short ToInt16(ulong value) { throw null; }

        public static int ToInt32(bool value) { throw null; }

        public static int ToInt32(byte value) { throw null; }

        public static int ToInt32(char value) { throw null; }

        public static int ToInt32(decimal value) { throw null; }

        public static int ToInt32(double value) { throw null; }

        public static int ToInt32(short value) { throw null; }

        public static int ToInt32(int value) { throw null; }

        public static int ToInt32(long value) { throw null; }

        public static int ToInt32(object value, IFormatProvider provider) { throw null; }

        public static int ToInt32(object value) { throw null; }

        [CLSCompliant(false)]
        public static int ToInt32(sbyte value) { throw null; }

        public static int ToInt32(float value) { throw null; }

        public static int ToInt32(string value, IFormatProvider provider) { throw null; }

        public static int ToInt32(string value, int fromBase) { throw null; }

        public static int ToInt32(string value) { throw null; }

        [CLSCompliant(false)]
        public static int ToInt32(ushort value) { throw null; }

        [CLSCompliant(false)]
        public static int ToInt32(uint value) { throw null; }

        [CLSCompliant(false)]
        public static int ToInt32(ulong value) { throw null; }

        public static long ToInt64(bool value) { throw null; }

        public static long ToInt64(byte value) { throw null; }

        public static long ToInt64(char value) { throw null; }

        public static long ToInt64(decimal value) { throw null; }

        public static long ToInt64(double value) { throw null; }

        public static long ToInt64(short value) { throw null; }

        public static long ToInt64(int value) { throw null; }

        public static long ToInt64(long value) { throw null; }

        public static long ToInt64(object value, IFormatProvider provider) { throw null; }

        public static long ToInt64(object value) { throw null; }

        [CLSCompliant(false)]
        public static long ToInt64(sbyte value) { throw null; }

        public static long ToInt64(float value) { throw null; }

        public static long ToInt64(string value, IFormatProvider provider) { throw null; }

        public static long ToInt64(string value, int fromBase) { throw null; }

        public static long ToInt64(string value) { throw null; }

        [CLSCompliant(false)]
        public static long ToInt64(ushort value) { throw null; }

        [CLSCompliant(false)]
        public static long ToInt64(uint value) { throw null; }

        [CLSCompliant(false)]
        public static long ToInt64(ulong value) { throw null; }

        [CLSCompliant(false)]
        public static sbyte ToSByte(bool value) { throw null; }

        [CLSCompliant(false)]
        public static sbyte ToSByte(byte value) { throw null; }

        [CLSCompliant(false)]
        public static sbyte ToSByte(char value) { throw null; }

        [CLSCompliant(false)]
        public static sbyte ToSByte(decimal value) { throw null; }

        [CLSCompliant(false)]
        public static sbyte ToSByte(double value) { throw null; }

        [CLSCompliant(false)]
        public static sbyte ToSByte(short value) { throw null; }

        [CLSCompliant(false)]
        public static sbyte ToSByte(int value) { throw null; }

        [CLSCompliant(false)]
        public static sbyte ToSByte(long value) { throw null; }

        [CLSCompliant(false)]
        public static sbyte ToSByte(object value, IFormatProvider provider) { throw null; }

        [CLSCompliant(false)]
        public static sbyte ToSByte(object value) { throw null; }

        [CLSCompliant(false)]
        public static sbyte ToSByte(sbyte value) { throw null; }

        [CLSCompliant(false)]
        public static sbyte ToSByte(float value) { throw null; }

        [CLSCompliant(false)]
        public static sbyte ToSByte(string value, IFormatProvider provider) { throw null; }

        [CLSCompliant(false)]
        public static sbyte ToSByte(string value, int fromBase) { throw null; }

        [CLSCompliant(false)]
        public static sbyte ToSByte(string value) { throw null; }

        [CLSCompliant(false)]
        public static sbyte ToSByte(ushort value) { throw null; }

        [CLSCompliant(false)]
        public static sbyte ToSByte(uint value) { throw null; }

        [CLSCompliant(false)]
        public static sbyte ToSByte(ulong value) { throw null; }

        public static float ToSingle(bool value) { throw null; }

        public static float ToSingle(byte value) { throw null; }

        public static float ToSingle(decimal value) { throw null; }

        public static float ToSingle(double value) { throw null; }

        public static float ToSingle(short value) { throw null; }

        public static float ToSingle(int value) { throw null; }

        public static float ToSingle(long value) { throw null; }

        public static float ToSingle(object value, IFormatProvider provider) { throw null; }

        public static float ToSingle(object value) { throw null; }

        [CLSCompliant(false)]
        public static float ToSingle(sbyte value) { throw null; }

        public static float ToSingle(float value) { throw null; }

        public static float ToSingle(string value, IFormatProvider provider) { throw null; }

        public static float ToSingle(string value) { throw null; }

        [CLSCompliant(false)]
        public static float ToSingle(ushort value) { throw null; }

        [CLSCompliant(false)]
        public static float ToSingle(uint value) { throw null; }

        [CLSCompliant(false)]
        public static float ToSingle(ulong value) { throw null; }

        public static string ToString(bool value, IFormatProvider provider) { throw null; }

        public static string ToString(bool value) { throw null; }

        public static string ToString(byte value, IFormatProvider provider) { throw null; }

        public static string ToString(byte value, int toBase) { throw null; }

        public static string ToString(byte value) { throw null; }

        public static string ToString(char value, IFormatProvider provider) { throw null; }

        public static string ToString(char value) { throw null; }

        public static string ToString(DateTime value, IFormatProvider provider) { throw null; }

        public static string ToString(DateTime value) { throw null; }

        public static string ToString(decimal value, IFormatProvider provider) { throw null; }

        public static string ToString(decimal value) { throw null; }

        public static string ToString(double value, IFormatProvider provider) { throw null; }

        public static string ToString(double value) { throw null; }

        public static string ToString(short value, IFormatProvider provider) { throw null; }

        public static string ToString(short value, int toBase) { throw null; }

        public static string ToString(short value) { throw null; }

        public static string ToString(int value, IFormatProvider provider) { throw null; }

        public static string ToString(int value, int toBase) { throw null; }

        public static string ToString(int value) { throw null; }

        public static string ToString(long value, IFormatProvider provider) { throw null; }

        public static string ToString(long value, int toBase) { throw null; }

        public static string ToString(long value) { throw null; }

        public static string ToString(object value, IFormatProvider provider) { throw null; }

        public static string ToString(object value) { throw null; }

        [CLSCompliant(false)]
        public static string ToString(sbyte value, IFormatProvider provider) { throw null; }

        [CLSCompliant(false)]
        public static string ToString(sbyte value) { throw null; }

        public static string ToString(float value, IFormatProvider provider) { throw null; }

        public static string ToString(float value) { throw null; }

        [CLSCompliant(false)]
        public static string ToString(ushort value, IFormatProvider provider) { throw null; }

        [CLSCompliant(false)]
        public static string ToString(ushort value) { throw null; }

        [CLSCompliant(false)]
        public static string ToString(uint value, IFormatProvider provider) { throw null; }

        [CLSCompliant(false)]
        public static string ToString(uint value) { throw null; }

        [CLSCompliant(false)]
        public static string ToString(ulong value, IFormatProvider provider) { throw null; }

        [CLSCompliant(false)]
        public static string ToString(ulong value) { throw null; }

        [CLSCompliant(false)]
        public static ushort ToUInt16(bool value) { throw null; }

        [CLSCompliant(false)]
        public static ushort ToUInt16(byte value) { throw null; }

        [CLSCompliant(false)]
        public static ushort ToUInt16(char value) { throw null; }

        [CLSCompliant(false)]
        public static ushort ToUInt16(decimal value) { throw null; }

        [CLSCompliant(false)]
        public static ushort ToUInt16(double value) { throw null; }

        [CLSCompliant(false)]
        public static ushort ToUInt16(short value) { throw null; }

        [CLSCompliant(false)]
        public static ushort ToUInt16(int value) { throw null; }

        [CLSCompliant(false)]
        public static ushort ToUInt16(long value) { throw null; }

        [CLSCompliant(false)]
        public static ushort ToUInt16(object value, IFormatProvider provider) { throw null; }

        [CLSCompliant(false)]
        public static ushort ToUInt16(object value) { throw null; }

        [CLSCompliant(false)]
        public static ushort ToUInt16(sbyte value) { throw null; }

        [CLSCompliant(false)]
        public static ushort ToUInt16(float value) { throw null; }

        [CLSCompliant(false)]
        public static ushort ToUInt16(string value, IFormatProvider provider) { throw null; }

        [CLSCompliant(false)]
        public static ushort ToUInt16(string value, int fromBase) { throw null; }

        [CLSCompliant(false)]
        public static ushort ToUInt16(string value) { throw null; }

        [CLSCompliant(false)]
        public static ushort ToUInt16(ushort value) { throw null; }

        [CLSCompliant(false)]
        public static ushort ToUInt16(uint value) { throw null; }

        [CLSCompliant(false)]
        public static ushort ToUInt16(ulong value) { throw null; }

        [CLSCompliant(false)]
        public static uint ToUInt32(bool value) { throw null; }

        [CLSCompliant(false)]
        public static uint ToUInt32(byte value) { throw null; }

        [CLSCompliant(false)]
        public static uint ToUInt32(char value) { throw null; }

        [CLSCompliant(false)]
        public static uint ToUInt32(decimal value) { throw null; }

        [CLSCompliant(false)]
        public static uint ToUInt32(double value) { throw null; }

        [CLSCompliant(false)]
        public static uint ToUInt32(short value) { throw null; }

        [CLSCompliant(false)]
        public static uint ToUInt32(int value) { throw null; }

        [CLSCompliant(false)]
        public static uint ToUInt32(long value) { throw null; }

        [CLSCompliant(false)]
        public static uint ToUInt32(object value, IFormatProvider provider) { throw null; }

        [CLSCompliant(false)]
        public static uint ToUInt32(object value) { throw null; }

        [CLSCompliant(false)]
        public static uint ToUInt32(sbyte value) { throw null; }

        [CLSCompliant(false)]
        public static uint ToUInt32(float value) { throw null; }

        [CLSCompliant(false)]
        public static uint ToUInt32(string value, IFormatProvider provider) { throw null; }

        [CLSCompliant(false)]
        public static uint ToUInt32(string value, int fromBase) { throw null; }

        [CLSCompliant(false)]
        public static uint ToUInt32(string value) { throw null; }

        [CLSCompliant(false)]
        public static uint ToUInt32(ushort value) { throw null; }

        [CLSCompliant(false)]
        public static uint ToUInt32(uint value) { throw null; }

        [CLSCompliant(false)]
        public static uint ToUInt32(ulong value) { throw null; }

        [CLSCompliant(false)]
        public static ulong ToUInt64(bool value) { throw null; }

        [CLSCompliant(false)]
        public static ulong ToUInt64(byte value) { throw null; }

        [CLSCompliant(false)]
        public static ulong ToUInt64(char value) { throw null; }

        [CLSCompliant(false)]
        public static ulong ToUInt64(decimal value) { throw null; }

        [CLSCompliant(false)]
        public static ulong ToUInt64(double value) { throw null; }

        [CLSCompliant(false)]
        public static ulong ToUInt64(short value) { throw null; }

        [CLSCompliant(false)]
        public static ulong ToUInt64(int value) { throw null; }

        [CLSCompliant(false)]
        public static ulong ToUInt64(long value) { throw null; }

        [CLSCompliant(false)]
        public static ulong ToUInt64(object value, IFormatProvider provider) { throw null; }

        [CLSCompliant(false)]
        public static ulong ToUInt64(object value) { throw null; }

        [CLSCompliant(false)]
        public static ulong ToUInt64(sbyte value) { throw null; }

        [CLSCompliant(false)]
        public static ulong ToUInt64(float value) { throw null; }

        [CLSCompliant(false)]
        public static ulong ToUInt64(string value, IFormatProvider provider) { throw null; }

        [CLSCompliant(false)]
        public static ulong ToUInt64(string value, int fromBase) { throw null; }

        [CLSCompliant(false)]
        public static ulong ToUInt64(string value) { throw null; }

        [CLSCompliant(false)]
        public static ulong ToUInt64(ushort value) { throw null; }

        [CLSCompliant(false)]
        public static ulong ToUInt64(uint value) { throw null; }

        [CLSCompliant(false)]
        public static ulong ToUInt64(ulong value) { throw null; }
    }

    public static partial class Environment
    {
        public static int CurrentManagedThreadId { get { throw null; } }

        public static bool HasShutdownStarted { get { throw null; } }

        public static string NewLine { get { throw null; } }

        public static int ProcessorCount { get { throw null; } }

        public static string StackTrace { get { throw null; } }

        public static int TickCount { get { throw null; } }

        public static string ExpandEnvironmentVariables(string name) { throw null; }

        public static void FailFast(string message, Exception exception) { }

        public static void FailFast(string message) { }

        public static string GetEnvironmentVariable(string variable) { throw null; }

        public static Collections.IDictionary GetEnvironmentVariables() { throw null; }

        public static void SetEnvironmentVariable(string variable, string value) { }
    }

    public static partial class Math
    {
        public const double E = 2.718281828459045D;
        public const double PI = 3.141592653589793D;
        public static decimal Abs(decimal value) { throw null; }

        public static double Abs(double value) { throw null; }

        public static short Abs(short value) { throw null; }

        public static int Abs(int value) { throw null; }

        public static long Abs(long value) { throw null; }

        [CLSCompliant(false)]
        public static sbyte Abs(sbyte value) { throw null; }

        public static float Abs(float value) { throw null; }

        public static double Acos(double d) { throw null; }

        public static double Asin(double d) { throw null; }

        public static double Atan(double d) { throw null; }

        public static double Atan2(double y, double x) { throw null; }

        public static decimal Ceiling(decimal d) { throw null; }

        public static double Ceiling(double a) { throw null; }

        public static double Cos(double d) { throw null; }

        public static double Cosh(double value) { throw null; }

        public static double Exp(double d) { throw null; }

        public static decimal Floor(decimal d) { throw null; }

        public static double Floor(double d) { throw null; }

        public static double IEEERemainder(double x, double y) { throw null; }

        public static double Log(double a, double newBase) { throw null; }

        public static double Log(double d) { throw null; }

        public static double Log10(double d) { throw null; }

        public static byte Max(byte val1, byte val2) { throw null; }

        public static decimal Max(decimal val1, decimal val2) { throw null; }

        public static double Max(double val1, double val2) { throw null; }

        public static short Max(short val1, short val2) { throw null; }

        public static int Max(int val1, int val2) { throw null; }

        public static long Max(long val1, long val2) { throw null; }

        [CLSCompliant(false)]
        public static sbyte Max(sbyte val1, sbyte val2) { throw null; }

        public static float Max(float val1, float val2) { throw null; }

        [CLSCompliant(false)]
        public static ushort Max(ushort val1, ushort val2) { throw null; }

        [CLSCompliant(false)]
        public static uint Max(uint val1, uint val2) { throw null; }

        [CLSCompliant(false)]
        public static ulong Max(ulong val1, ulong val2) { throw null; }

        public static byte Min(byte val1, byte val2) { throw null; }

        public static decimal Min(decimal val1, decimal val2) { throw null; }

        public static double Min(double val1, double val2) { throw null; }

        public static short Min(short val1, short val2) { throw null; }

        public static int Min(int val1, int val2) { throw null; }

        public static long Min(long val1, long val2) { throw null; }

        [CLSCompliant(false)]
        public static sbyte Min(sbyte val1, sbyte val2) { throw null; }

        public static float Min(float val1, float val2) { throw null; }

        [CLSCompliant(false)]
        public static ushort Min(ushort val1, ushort val2) { throw null; }

        [CLSCompliant(false)]
        public static uint Min(uint val1, uint val2) { throw null; }

        [CLSCompliant(false)]
        public static ulong Min(ulong val1, ulong val2) { throw null; }

        public static double Pow(double x, double y) { throw null; }

        public static decimal Round(decimal d, int decimals, MidpointRounding mode) { throw null; }

        public static decimal Round(decimal d, int decimals) { throw null; }

        public static decimal Round(decimal d, MidpointRounding mode) { throw null; }

        public static decimal Round(decimal d) { throw null; }

        public static double Round(double value, int digits, MidpointRounding mode) { throw null; }

        public static double Round(double value, int digits) { throw null; }

        public static double Round(double value, MidpointRounding mode) { throw null; }

        public static double Round(double a) { throw null; }

        public static int Sign(decimal value) { throw null; }

        public static int Sign(double value) { throw null; }

        public static int Sign(short value) { throw null; }

        public static int Sign(int value) { throw null; }

        public static int Sign(long value) { throw null; }

        [CLSCompliant(false)]
        public static int Sign(sbyte value) { throw null; }

        public static int Sign(float value) { throw null; }

        public static double Sin(double a) { throw null; }

        public static double Sinh(double value) { throw null; }

        public static double Sqrt(double d) { throw null; }

        public static double Tan(double a) { throw null; }

        public static double Tanh(double value) { throw null; }

        public static decimal Truncate(decimal d) { throw null; }

        public static double Truncate(double d) { throw null; }
    }

    public enum MidpointRounding
    {
        ToEven = 0,
        AwayFromZero = 1
    }

    public partial class Progress<T> : IProgress<T>
    {
        public Progress() { }

        public Progress(Action<T> handler) { }

        public event EventHandler<T> ProgressChanged { add { } remove { } }

        protected virtual void OnReport(T value) { }

        void IProgress<T>.Report(T value) { }
    }

    public partial class Random
    {
        public Random() { }

        public Random(int Seed) { }

        public virtual int Next() { throw null; }

        public virtual int Next(int minValue, int maxValue) { throw null; }

        public virtual int Next(int maxValue) { throw null; }

        public virtual void NextBytes(byte[] buffer) { }

        public virtual double NextDouble() { throw null; }

        protected virtual double Sample() { throw null; }
    }

    public abstract partial class StringComparer : Collections.Generic.IComparer<string>, Collections.Generic.IEqualityComparer<string>, Collections.IComparer, Collections.IEqualityComparer
    {
        public static StringComparer CurrentCulture { get { throw null; } }

        public static StringComparer CurrentCultureIgnoreCase { get { throw null; } }

        public static StringComparer Ordinal { get { throw null; } }

        public static StringComparer OrdinalIgnoreCase { get { throw null; } }

        public abstract int Compare(string x, string y);
        public abstract bool Equals(string x, string y);
        public abstract int GetHashCode(string obj);
        int Collections.IComparer.Compare(object x, object y) { throw null; }

        bool Collections.IEqualityComparer.Equals(object x, object y) { throw null; }

        int Collections.IEqualityComparer.GetHashCode(object obj) { throw null; }
    }

    public partial class UriBuilder
    {
        public UriBuilder() { }

        public UriBuilder(string scheme, string host, int port, string path, string extraValue) { }

        public UriBuilder(string scheme, string host, int port, string pathValue) { }

        public UriBuilder(string scheme, string host, int portNumber) { }

        public UriBuilder(string schemeName, string hostName) { }

        public UriBuilder(string uri) { }

        public UriBuilder(Uri uri) { }

        public string Fragment { get { throw null; } set { } }

        public string Host { get { throw null; } set { } }

        public string Password { get { throw null; } set { } }

        public string Path { get { throw null; } set { } }

        public int Port { get { throw null; } set { } }

        public string Query { get { throw null; } set { } }

        public string Scheme { get { throw null; } set { } }

        public Uri Uri { get { throw null; } }

        public string UserName { get { throw null; } set { } }

        public override bool Equals(object rparam) { throw null; }

        public override int GetHashCode() { throw null; }

        public override string ToString() { throw null; }
    }
}

namespace System.Diagnostics
{
    public partial class Stopwatch
    {
        public static readonly long Frequency;
        public static readonly bool IsHighResolution;
        public TimeSpan Elapsed { get { throw null; } }

        public long ElapsedMilliseconds { get { throw null; } }

        public long ElapsedTicks { get { throw null; } }

        public bool IsRunning { get { throw null; } }

        public static long GetTimestamp() { throw null; }

        public void Reset() { }

        public void Restart() { }

        public void Start() { }

        public static Stopwatch StartNew() { throw null; }

        public void Stop() { }
    }
}

namespace System.IO
{
    public static partial class Path
    {
        public static readonly char AltDirectorySeparatorChar;
        public static readonly char DirectorySeparatorChar;
        public static readonly char PathSeparator;
        public static readonly char VolumeSeparatorChar;
        public static string ChangeExtension(string path, string extension) { throw null; }

        public static string Combine(string path1, string path2, string path3) { throw null; }

        public static string Combine(string path1, string path2) { throw null; }

        public static string Combine(params string[] paths) { throw null; }

        public static string GetDirectoryName(string path) { throw null; }

        public static string GetExtension(string path) { throw null; }

        public static string GetFileName(string path) { throw null; }

        public static string GetFileNameWithoutExtension(string path) { throw null; }

        public static string GetFullPath(string path) { throw null; }

        public static char[] GetInvalidFileNameChars() { throw null; }

        public static char[] GetInvalidPathChars() { throw null; }

        public static string GetPathRoot(string path) { throw null; }

        public static string GetRandomFileName() { throw null; }

        public static string GetTempFileName() { throw null; }

        public static string GetTempPath() { throw null; }

        public static bool HasExtension(string path) { throw null; }

        public static bool IsPathRooted(string path) { throw null; }
    }
}

namespace System.Net
{
    public static partial class WebUtility
    {
        public static string HtmlDecode(string value) { throw null; }

        public static string HtmlEncode(string value) { throw null; }

        public static string UrlDecode(string encodedValue) { throw null; }

        public static byte[] UrlDecodeToBytes(byte[] encodedValue, int offset, int count) { throw null; }

        public static string UrlEncode(string value) { throw null; }

        public static byte[] UrlEncodeToBytes(byte[] value, int offset, int count) { throw null; }
    }
}

namespace System.Runtime.Versioning
{
    public sealed partial class FrameworkName : IEquatable<FrameworkName>
    {
        public FrameworkName(string identifier, Version version, string profile) { }

        public FrameworkName(string identifier, Version version) { }

        public FrameworkName(string frameworkName) { }

        public string FullName { get { throw null; } }

        public string Identifier { get { throw null; } }

        public string Profile { get { throw null; } }

        public Version Version { get { throw null; } }

        public override bool Equals(object obj) { throw null; }

        public bool Equals(FrameworkName other) { throw null; }

        public override int GetHashCode() { throw null; }

        public static bool operator ==(FrameworkName left, FrameworkName right) { throw null; }

        public static bool operator !=(FrameworkName left, FrameworkName right) { throw null; }

        public override string ToString() { throw null; }
    }
}